"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NftService = void 0;
var tslib_1 = require("tslib");
var axios_1 = tslib_1.__importDefault(require("axios"));
var client = axios_1.default.create({
    baseURL: 'http://3.87.203.10/api-service',
});
var NftService = /** @class */ (function () {
    function NftService() {
        var _this = this;
        // Gets native transactions
        this.getAccountHistory = function (address) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var result;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, client.get("/account/".concat(address))];
                    case 1:
                        result = _a.sent();
                        return [2 /*return*/, result.data];
                }
            });
        }); };
        // Get collection of nft owned by the given address
        //If token_address is provided get the nfts owned by the given address for a specific NFT contract address
        this.getNftDetails = function (address, token_address) {
            if (token_address === void 0) { token_address = ''; }
            return tslib_1.__awaiter(_this, void 0, void 0, function () {
                var result, result;
                return tslib_1.__generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            if (!(token_address !== '')) return [3 /*break*/, 2];
                            return [4 /*yield*/, client.get("/account/".concat(address, "/nft/").concat(token_address))];
                        case 1:
                            result = _a.sent();
                            return [2 /*return*/, result.data];
                        case 2: return [4 /*yield*/, client.get("/account/".concat(address, "/nft"))];
                        case 3:
                            result = _a.sent();
                            return [2 /*return*/, result.data];
                    }
                });
            });
        };
        // Get transfers of the tokens for the given address'
        this.getAccountTransactions = function (address) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var result;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, client.get("/account/".concat(address, "/nft/transfers"))];
                    case 1:
                        result = _a.sent();
                        return [2 /*return*/, result.data];
                }
            });
        }); };
        // Get token balances for a specific address
        this.getTokenBalance = function (address) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var result;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, client.get("/account/".concat(address, "/erc20"))];
                    case 1:
                        result = _a.sent();
                        return [2 /*return*/, result.data];
                }
            });
        }); };
        // Gets ERC20 token transactions in descending order based on block number
        this.getErc20TokenTransfers = function (address, to_block, from_block) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var result, result;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!(to_block && from_block)) return [3 /*break*/, 2];
                        return [4 /*yield*/, client.get("/account/".concat(address, "/erc20/transfers?to_block=").concat(to_block, "&from_block=").concat(from_block))];
                    case 1:
                        result = _a.sent();
                        return [2 /*return*/, result.data];
                    case 2: return [4 /*yield*/, client.get("/account/".concat(address, "/erc20/transfers"))];
                    case 3:
                        result = _a.sent();
                        return [2 /*return*/, result.data];
                }
            });
        }); };
        // Get the contents of a block by block number or block hash
        this.getBlockContent = function (block_info) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var result;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, client.get("/block/".concat(block_info))];
                    case 1:
                        result = _a.sent();
                        return [2 /*return*/, result.data];
                }
            });
        }); };
        // Get the logs for an address
        this.getTransactionLogs = function (address) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var result;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, client.get("/".concat(address, "/logs"))];
                    case 1:
                        result = _a.sent();
                        return [2 /*return*/, result.data];
                }
            });
        }); };
        // Get transaction for which the hash is provided
        this.getTransactionDetails = function (transactionHash) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var result;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, client.get("/transaction/".concat(transactionHash))];
                    case 1:
                        result = _a.sent();
                        return [2 /*return*/, result.data];
                }
            });
        }); };
        // Retrieve metadata for nfts
        this.getContractLevelMetadata = function (address) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var result;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, client.get("/token/nft/".concat(address, "/metadata"))];
                    case 1:
                        result = _a.sent();
                        return [2 /*return*/, result.data];
                }
            });
        }); };
        // Update metadata for nfts
        this.resyncMetadataOfNft = function (address, token_id) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var result;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, client.get("/token/nft/".concat(address, "/").concat(token_id, "/metadata/resync"))];
                    case 1:
                        result = _a.sent();
                        return [2 /*return*/, result.data];
                }
            });
        }); };
        // Get metadata for given contract address
        this.getMetadata = function (value) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var result;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, client.get("/token/erc20/metadata?addresses=".concat(value))];
                    case 1:
                        result = _a.sent();
                        return [2 /*return*/, result.data];
                }
            });
        }); };
    }
    return NftService;
}());
exports.NftService = NftService;
//# sourceMappingURL=index.js.map