import { ethers } from 'ethers';
/**
 * Setup ethers with provider
 * ___________________________________
 * @param rpcURL - Eth/Poly/BSC RPC URL
 * @returns rpc provider
 */
declare const setupProvider: (rpcURL: string) => Promise<ethers.providers.JsonRpcProvider | ethers.providers.WebSocketProvider>;
/**
 * Setup ethers signer with private key
 * ____________________________________
 * @param pKey - Private Key for admin
 * @param provider - rpc provider
 */
declare const setupSigner: (pKey: string, provider: ethers.providers.JsonRpcProvider) => Promise<ethers.Wallet>;
/**
 * get Contract instance from contract name
 * ___________________________________________
 * @param wallet - ethers signer
 * @param contractName - name of the contract required eg: ERC20, ERC721.
 * @param contractAddress - contract address
 * @returns signer instance
 * @example
 * const contract = await getContract(signer, 'BSC_CONTRACT_NAME', '0x0000...0000')
 */
declare const getContract: (wallet: ethers.Wallet, contractName: string, contractAddress: string) => ethers.Contract;
export default setupProvider;
export { setupSigner, getContract };
