"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getContract = exports.setupSigner = void 0;
var tslib_1 = require("tslib");
var ethers_1 = require("ethers");
var ERC20 = tslib_1.__importStar(require("../abis/ERC20.json"));
var ERC721 = tslib_1.__importStar(require("../abis/ERC721.json"));
var ERC1155 = tslib_1.__importStar(require("../abis/ERC1155.json"));
var WalletRegistry = tslib_1.__importStar(require("../abis/WalletRegistry.json"));
var JSONMap = {
    ERC20: ERC20,
    ERC721: ERC721,
    ERC1155: ERC1155,
    WalletRegistry: WalletRegistry
};
/**
 * Setup ethers with provider
 * ___________________________________
 * @param rpcURL - Eth/Poly/BSC RPC URL
 * @returns rpc provider
 */
var setupProvider = function (rpcURL) { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
    var url, provider;
    return tslib_1.__generator(this, function (_a) {
        url = new URL(rpcURL);
        if (url.protocol === 'wss:') {
            provider = new ethers_1.ethers.providers.WebSocketProvider(rpcURL);
            return [2 /*return*/, provider];
        }
        provider = new ethers_1.ethers.providers.JsonRpcProvider(rpcURL);
        return [2 /*return*/, provider];
    });
}); };
/**
 * Setup ethers signer with private key
 * ____________________________________
 * @param pKey - Private Key for admin
 * @param provider - rpc provider
 */
var setupSigner = function (pKey, provider) { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
    var signer;
    return tslib_1.__generator(this, function (_a) {
        signer = new ethers_1.ethers.Wallet(pKey, provider);
        console.log("\u2705 Signer Address : ".concat(signer.address));
        return [2 /*return*/, signer];
    });
}); };
exports.setupSigner = setupSigner;
/**
 * get ABI contract name
 * ___________________________________________
 * @param contractName - name of the contract required eg: ERC20, ERC721.
 * @returns ABI
 * @example
 * const abi = _getContractABIFromJSON('ERC20')
 */
// eslint-disable-next-line @typescript-eslint/no-var-requires
var _getContractABIFromJSON = function (contractName) {
    return JSONMap[contractName];
};
/**
 * get Contract instance from contract name
 * ___________________________________________
 * @param wallet - ethers signer
 * @param contractName - name of the contract required eg: ERC20, ERC721.
 * @param contractAddress - contract address
 * @returns signer instance
 * @example
 * const contract = await getContract(signer, 'BSC_CONTRACT_NAME', '0x0000...0000')
 */
var getContract = function (wallet, contractName, contractAddress) {
    var contractJson = _getContractABIFromJSON(contractName);
    return new ethers_1.ethers.Contract(contractAddress, contractJson.abi, wallet);
};
exports.getContract = getContract;
exports.default = setupProvider;
//# sourceMappingURL=ethers.js.map